#[repr(u8)]pub enum Dmode {
DMODE_0 = 0,
DMODE_1 = 1,
}Variants
DMODE_0 = 0
DAC is selected to work in low speed and low power mode.
DMODE_1 = 1
DAC is selected to work in high speed high power mode.
Implementations