#[repr(u8)]pub enum Fxmp {
FXMP_0 = 0,
FXMP_1 = 1,
}Variants
FXMP_0 = 0
The Plus port is fixed. Only the inputs to the Minus port are swept in each round.
FXMP_1 = 1
The Minus port is fixed. Only the inputs to the Plus port are swept in each round.
Implementations