#[repr(u8)]pub enum Fxmxch {
FXMXCH_0 = 0,
FXMXCH_1 = 1,
FXMXCH_2 = 2,
FXMXCH_3 = 3,
FXMXCH_4 = 4,
FXMXCH_5 = 5,
_RESERVED_6 = 6,
FXMXCH_7 = 7,
}Variants
FXMXCH_0 = 0
External Reference Input 0 is selected as the fixed reference input for the fixed mux port.
FXMXCH_1 = 1
External Reference Input 1 is selected as the fixed reference input for the fixed mux port.
FXMXCH_2 = 2
External Reference Input 2 is selected as the fixed reference input for the fixed mux port.
FXMXCH_3 = 3
External Reference Input 3 is selected as the fixed reference input for the fixed mux port.
FXMXCH_4 = 4
External Reference Input 4 is selected as the fixed reference input for the fixed mux port.
FXMXCH_5 = 5
External Reference Input 5 is selected as the fixed reference input for the fixed mux port.
_RESERVED_6 = 6
FXMXCH_7 = 7
The 8bit DAC is selected as the fixed reference input for the fixed mux port.
Implementations