#[repr(u8)]pub enum Nchcten {
NCHCTEN_0 = 0,
NCHCTEN_1 = 1,
}Variants
NCHCTEN_0 = 0
Negative channel is in Discrete Mode and special timing needs to be configured.
NCHCTEN_1 = 1
Negative channel is in Continuous Mode and no special timing is requried.
Implementations