#[repr(u8)]pub enum Pchcten {
PCHCTEN_0 = 0,
PCHCTEN_1 = 1,
}Variants
PCHCTEN_0 = 0
Positive channel is in Discrete Mode and special timing needs to be configured.
PCHCTEN_1 = 1
Positive channel is in Continuous Mode and no special timing is requried.
Implementations