#[repr(u8)]pub enum Rdive {
RDIVE_0 = 0,
RDIVE_1 = 1,
}Variants
RDIVE_0 = 0
The resistor is not enabled even when either NCHEN or PCHEN is set to1 but the actual input is in the range of 0 - 1.8v.
RDIVE_1 = 1
The resistor is enabled because the inputs are above 1.8v.
Implementations